%define build_attestation_imc_imv 1

Summary: An open source implementation of the Trusted Network Connect (TNC) framework
Name: tncfhh
Version: 0.8.2

Release: 2%{?dist}
License: GPLv2
Url: http://trust.inform.fh-hannover.de/joomla/index.php/projects/tncfhh
Source0: http://trust.inform.fh-hannover.de/download/tncfhh/tncfhh-%{version}.tar.gz

Group: Applications/System
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: cmake log4cxx-devel xerces-c-devel trousers-devel libtnc-devel
BuildRequires: libtool-ltdl-devel boost-devel openssl-devel

Patch1: tncxacml-xerces.patch
Patch2: tncfhh-cmake-issues.patch
Patch3: tncfhh-memory-leak-exception.patch
Patch4: tncfhh-0.8.2-issues.patch

%description
The TNC@FHH project is an open source implementation of the Trusted Network
Connect (TNC) framework, which is specified by the Trusted Computing Group
(TCG). TNC@FHH allows you to provision access to a network based upon
factors like the user credentials and the requesting endpoint's integrity state.

The following TNC components and their respective interfaces are implemented by
TNC@FHH: IMCs (IF-IMC 1.2), IMVs (IF-IMV 1.2), TNCS (IF-TNCCS 1.1), 
NAA (IF-T EAP 1.1).

%package libs
Summary: Dynamic library for TNC
License: GPLv2
Group: Development/Libraries
Requires: %{name} = %{version}
Requires: boost-thread boost-system

%description libs
This package provides naaeap, tnsc, imunit, tncutil, and tncxacml 
dynamic libraries for using TNC client and server interfaces.

%package devel
Summary: Development files for TNC
License: GPLv2
Group: Development/Libraries
Requires: %{name}-libs = %{version}
Requires: %{name}-examples = %{version}
Requires: %{name}-utils = %{version}

%description devel
This package contains the header files needed for developing 
IMC and IMV pairs.

%package examples
Summary: Example IMC/IMV implementations
License: GPLv2
Group: Applications/System
Requires: %{name}-libs = %{version}

%description examples
This package provides some example implementations of several 
IMC/IMV pairs.

%package utils
Summary: Dynamic library for TNC utilities
License: GPLv2
Group: Development/Libraries

%description utils
A shared library that offers simple configuration file parsing.

%prep
%setup -q -n tncfhh-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%cmake . -DCOMPONENT=all -DNAL=8021x \
%if %{build_attestation_imc_imv}
 -DTPM=on
%endif
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_libdir}
make install DESTDIR=${RPM_BUILD_ROOT} INSTALL='install -p'

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -n tncfhh-libs  -p /sbin/ldconfig
%postun -n tncfhh-libs  -p /sbin/ldconfig

%post -n tncfhh-utils  -p /sbin/ldconfig
%postun -n tncfhh-utils -p /sbin/ldconfig

%post -n tncfhh-examples  -p /sbin/ldconfig
%postun -n tncfhh-examples  -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc README LICENSE doc/tncfhh.pdf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/tnc_config
%{_libdir}/libimunit.so.?
%{_libdir}/libimunit.so.?.?.?

%files libs
%{_libdir}/libnaaeap.so.?
%{_libdir}/libnaaeap.so.?.?.?
%{_libdir}/libtncs.so.?
%{_libdir}/libtncs.so.?.?.?
%{_libdir}/libtncxacml.so.?
%{_libdir}/libtncxacml.so.?.?.?
%attr(0755,root,root) %dir %{_sysconfdir}/tnc
%attr(0755,root,root) %dir %{_sysconfdir}/tnc/xacml
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/tnc/xacml/*

%files devel
%defattr(-,root,root,-)
%{_includedir}/tncfhhConfig.h
%{_includedir}/naaeap/
%attr(0755, root, root) %{_libdir}/libnaaeap.so
%{_includedir}/tncs/
%attr(0755, root, root) %{_libdir}/libtncs.so
%{_includedir}/tcg/tnc/
%{_includedir}/imunit/
%attr(0755, root, root) %{_libdir}/libimunit.so
%{_includedir}/tncutil/
%attr(0755, root, root) %{_libdir}/libtncutil.so
%{_includedir}/tncxacml/
%attr(0755, root, root) %{_libdir}/libtncxacml.so
%attr(0755, root, root) %{_libdir}/libdummy*.so
%attr(0755, root, root) %{_libdir}/libhostscanner*.so
%attr(0755, root, root) %{_libdir}/libclamav*.so
%attr(0755, root, root) %{_libdir}/libexample*.so
%attr(0755, root, root) %{_libdir}/libplatid*.so
%if %{build_attestation_imc_imv}
%attr(0755, root, root) %{_libdir}/libattestation*.so
%endif

%files examples
%defattr(-,root,root,-)
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/tnc/*.*
%{_libdir}/libdummy*.so.*
%{_libdir}/libhostscanner*.so.*
%{_libdir}/libclamav*.so.*
%{_libdir}/libexample*.so.*
%{_libdir}/libplatid*.so.*
%if %{build_attestation_imc_imv}
%{_libdir}/libattestation*.so.*
%endif

%files utils
%{_libdir}/libtncutil.so.?
%{_libdir}/libtncutil.so.?.?.?

%changelog
* Mon Aug 8 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.8.2-2
- Fixed broken dependencies of boost-system and boost-thread
- Fixed some performance and implementation issues

* Mon Jul 18 2011 Avesh Agarwal <avagarwa@redhat.com> - 0.8.2-1
- Initial packaging of tncfhh-0.8.2
- Fixed cmake issues
- Fixed xerces issues
- Fixed memory leak and exception issue
